## Summary

Brief description of changes.

## Changes

- [ ] New tool / prompt / resource
- [ ] Bug fix
- [ ] Refactor
- [ ] Documentation
- [ ] CI/CD

## Testing

- [ ] `uv run pytest tests/ -v` — all tests pass
- [ ] `uv run ruff check src/ tests/` — no lint errors
- [ ] `uv run mypy src/mcp_zuul/` — no type errors
- [ ] New tests added for new functionality
